Skip to content
KernelIndex
Search⌘K

submission 779776

ajay_a · python · License unknown

Use it

Vendorable · source mirrored · license unknownView source →

No package. Vendor the mirrored source: 26 lines, June 9 Researcher Reciprocity License v1.0.

submission.py
curl "https://kernelindex.com/api/v1/implementations/kernelbot-vectoradd-v2-779776?include=source"
interfacepython
Compatibility
measured onNVIDIA B200
declared hardwareNVIDIA B200
architecturessm_100
dtypesfp16

Benchmark evidence

1 measurement across 1 GPU, fastest first.

Operation / workload
Hardware
Latency
Rank
Observed
FP16 vector additionsuite of 5 cases
NVIDIA B200
238.9µs
#42 of 66
2026-04-23

Reported · How evidence levels are derived →

Source and license

sourceavailable
revision digestsha256:9717eccd8ef76161994f31b59cf3b24cef7e69a5fb2d93b3d101c89d369c5b89
license declaredunknown
license concludedunknown
authorsajay_a
imported2026-08-15

Kernel source

submission.py26 lines
#!POPCORN leaderboard vectoradd_v2
#!POPCORN gpu B200

from task import input_t, output_t
import triton
import triton.language as tl


@triton.jit
def add_kernel(a_ptr, b_ptr, out_ptr, n, BLOCK: tl.constexpr):
    pid = tl.program_id(0)
    offs = pid * BLOCK + tl.arange(0, BLOCK)
    mask = offs < n
    a = tl.load(a_ptr + offs, mask=mask)
    b = tl.load(b_ptr + offs, mask=mask)
    tl.store(out_ptr + offs, a + b, mask=mask)


def custom_kernel(data: input_t) -> output_t:
    A, B, output = data
    n = A.numel()
    BLOCK = 1024
    grid = (triton.cdiv(n, BLOCK),)
    add_kernel[grid](A, B, output, n, BLOCK=BLOCK)
    return output

Source code from GPU Mode and the KernelBot dataset · June 9 Researcher Reciprocity License v1.0

Best evidence level for this revision: reported

JSON